<?php

/**
 * Storefront engine room
 *
 * @package storefront
 */

/**
 * Assign the Storefront version to a var
 */
$theme              = wp_get_theme('storefront');
$storefront_version = $theme['Version'];

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if (!isset($content_width)) {
    $content_width = 980; /* pixels */
}

$storefront = (object) array(
    'version'    => $storefront_version,

    /**
     * Initialize all the things.
     */
    'main'       => require 'inc/class-storefront.php',
    'customizer' => require 'inc/customizer/class-storefront-customizer.php',
);

require 'inc/storefront-functions.php';
require 'inc/storefront-template-hooks.php';
require 'inc/storefront-template-functions.php';
require 'inc/wordpress-shims.php';

if (class_exists('Jetpack')) {
    $storefront->jetpack = require 'inc/jetpack/class-storefront-jetpack.php';
}

if (storefront_is_woocommerce_activated()) {
    $storefront->woocommerce            = require 'inc/woocommerce/class-storefront-woocommerce.php';
    $storefront->woocommerce_customizer = require 'inc/woocommerce/class-storefront-woocommerce-customizer.php';

    require 'inc/woocommerce/class-storefront-woocommerce-adjacent-products.php';

    require 'inc/woocommerce/storefront-woocommerce-template-hooks.php';
    require 'inc/woocommerce/storefront-woocommerce-template-functions.php';
    require 'inc/woocommerce/storefront-woocommerce-functions.php';
}

if (is_admin()) {
    $storefront->admin = require 'inc/admin/class-storefront-admin.php';

    require 'inc/admin/class-storefront-plugin-install.php';
}

/**
 * NUX
 * Only load if wp version is 4.7.3 or above because of this issue;
 * https://core.trac.wordpress.org/ticket/39610?cversion=1&cnum_hist=2
 */
if (version_compare(get_bloginfo('version'), '4.7.3', '>=') && (is_admin() || is_customize_preview())) {
    require 'inc/nux/class-storefront-nux-admin.php';
    require 'inc/nux/class-storefront-nux-guided-tour.php';
    require 'inc/nux/class-storefront-nux-starter-content.php';
}

/**
 * Note: Do not add any custom code here. Please use a custom plugin so that your customizations aren't lost during updates.
 * https://github.com/woocommerce/theme-customisations
 */

function getTotalGalleryArray($posts_data)
{
    $imagesArray = [];
    foreach ($posts_data->posts as $post_data) {
        $post_id = $post_data->ID;
        if ($post_id == 33) {
            $images = get_post_gallery_images($post_id);
            foreach ($images as $image) {
                $imagesArray[] = [
                    'url' => $image
                ];
            }
        }
    }
    return $imagesArray;
}

add_filter('wpcf7_autop_or_not', '__return_false');


// custom post type..


// Register Post
function register_Portfolio_post()
{
    $labels = array(
        'name'                => _x('Districts', 'Post Type General Name', 'storefront'),
        'singular_name'       => _x('District', 'Post Type Singular Name', 'storefront'),
        'menu_name'           => __('Districts', 'storefront'),
        'parent_item_colon'   => __('Parent District', 'storefront'),
        'all_items'           => __('All Districts', 'storefront'),
        'view_item'           => __('View District', 'storefront'),
        'add_new_item'        => __('Add New District', 'storefront'),
        'add_new'             => __('Add New', 'storefront'),
        'edit_item'           => __('Edit District', 'storefront'),
        'update_item'         => __('Update District', 'storefront'),
        'search_items'        => __('Search District', 'storefront'),
        'not_found'           => __('Not Found', 'storefront'),
        'not_found_in_trash'  => __('Not found in Trash', 'storefront'),
    );
    $args = array(
        'label'               => __('Districts', 'storefront'),
        'description'         => __('District and reviews', 'storefront'),
        'labels'              => $labels,
        'supports'            => array('title', 'editor', 'author', 'thumbnail', 'custom-fields', 'comments', 'revisions', 'excerpt'),
        // 'taxonomies'          => array( 'district_list' ),
        'hierarchical'        => false,
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_nav_menus'   => true,
        'show_in_admin_bar'   => true,
        'menu_position'       => 5,
        'can_export'          => true,
        'has_archive'         => false,
        'rewrite' => array('slug' => 'district'),
        'exclude_from_search' => false,
        'publicly_queryable'  => true,
        'capability_type'     => 'post',
        'show_in_rest' => true,

    );
    register_post_type('district', $args);
}
add_action('init', 'register_Portfolio_post');

// Register Taxonomy
function portfolio_register_taxonomy()
{
    register_taxonomy(
        'district_list',
        'district',
        array(
            'labels' => array(
                'name' => 'District Lists',
                'add_new_item' => 'Add New',
                'new_item_name' => "New District Lists"
            ),
            'show_ui' => true,
            'show_tagcloud' => false,
            'hierarchical' => true,
            'hasArchive' => true
        )
    );
}
add_action('init', 'portfolio_register_taxonomy');

function AllRelatedPosts($term_id){
$args=[];
$args['post_type']= 'district';
$args['post_status']= 'publish';
$args['posts_per_page']= -1;
// $args['paged']= $paged;
if(!empty($term_id)){
    $args['tax_query']= [
        [
            'taxonomy'=>'district_list',
            'field'=>'term_id',
            'terms'=>$term_id,
        ]
    ];
}
$args['orderby']= 'title';
$args['order']= 'asc';
 return $posts_data = new WP_Query($args);
}

// function for upcoming and past events.

add_action("recent_event_action_hook","events_hook_fn");
function events_hook_fn(){
    $args = [];
    $args['post_type'] = 'post';
    $args['post_status'] = 'publish';
    $args['posts_per_page'] = -1;
    $args['order'] = 'ASC';
    $posts_data = new WP_Query($args); 
    $date = strtotime(date('d/m/Y'));
    foreach($posts_data->posts as $post_data){
    $post_id = $post_data->ID;
    $event_start = strtotime(get_field('event_start_date',$post_id));
    $event_end = strtotime(get_field('event_end_date',$post_id));
    if(get_field('event_start_date',$post_id) > $date){
    }
    if(!empty($event_end) ? $event_end >= $date : $event_start >= $date){
    ?>
    <li>
        <div class="event_figure">
            <img src="<?= get_the_post_thumbnail_url($post_id);?>" alt="">
        </div>
        <div class="event_caption">
            <a href="#"><i class="bi bi-calendar-event"></i> <?= get_field('event_start_date',$post_id);?> </a>
            <a href="<?= get_permalink($past_post_id);?>"><?= get_the_title($post_id);?></a>
        </div>
    </li>
    <?php    
    }    
    }
}

add_action("past_event_action_hook","past_events_hook_fn");
function past_events_hook_fn(){
    $args = [];
    $args['post_type'] = 'post';
    $args['post_status'] = 'publish';
    $args['posts_per_page'] = -1;
    $args['order'] = 'ASC';
    $posts_data = new WP_Query($args); 
    $date = strtotime(date('d/m/Y'));
    foreach($posts_data->posts as $row_post_data){
        $past_post_id = $row_post_data->ID;
        $event_start = strtotime(get_field('event_start_date',$past_post_id));
        $event_end = strtotime(get_field('event_end_date',$past_post_id));
        
        if(!empty($event_end) ? $event_end < $date : $event_start < $date){
        ?>
        <li>
            <div class="event_figure">
                <img src="<?= get_the_post_thumbnail_url($past_post_id);?>" alt="">
            </div>
            <div class="event_caption">
                <a href="#"><i class="bi bi-calendar-event"></i> <?= get_field('event_start_date',$past_post_id);?> </a>
                <a href="<?= get_permalink($past_post_id);?>"><?= get_the_title($past_post_id);?></a>
            </div>
        </li>
        <?php
        }
    }
}

// district slider ..

add_action('district_page_slider_hook','district_page_slider_fn');
function district_page_slider_fn(){
$queried_object = get_queried_object();
$term_name = $queried_object->name;
$post_id = $posts_data->post->ID;
?>
<section class="slider_area">
    <div class="main_slider owl-carousel owl-theme">
        <?php
        $sliders = get_field('district_slider', $post_id);
        foreach ($sliders as $slider) {
        ?>
            <div class="item">
                <img src="<?= $slider['slider_image']; ?>" class="img-fluid" alt="">
                <div class="owl_caption">
                    <div class="container">
                        <div class="row">
                            <div class="col-md-12 text-center">
                                <h1 class="breadcrumb_title"><?= $term_name; ?></h1>
                                <nav aria-label="breadcrumb">
                                    <ol class="breadcrumb">
                                        <li class="breadcrumb-item"><a href="<?= site_url(''); ?>">Home</a></li>
                                        <li class="breadcrumb-item active" aria-current="page"><?= $term_name; ?></li>
                                    </ol>
                                </nav>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }
        ?>
    </div>
</section>
<?php
}

// Function For A to Z Pagination.

function get_pagination_ajax(){
    if(!empty($_POST['alphabet']))
    {
    ?>
        <table id="examples" class="table table-bordered table-striped table-hover sm-responsive">
            <thead>
                <tr class="align-middle">
                    <th scope="col" class="custom_color">Sr. No</th>
                    <th scope="col" class="custom_color">Name</th>
                    <th scope="col" class="custom_color">Firm Name</th>
                    <th scope="col" class="custom_color">Business Address</th>
                    <th scope="col" class="custom_color">Action</th>
                    <!--<th scope="col" class="custom_color">Nature of Business</th>-->
                </tr>
            </thead>
            <tbody id="myTable" class="tegfn">
                <?php
                global $wpdb;
                $alphabet_data = $_POST['alphabet'];
                if($alphabet_data == "All"){
                    $n = $wpdb->get_results( "SELECT * FROM wp_membership_reg");
                }else{
                    $n = $wpdb->get_results( "SELECT * FROM wp_membership_reg WHERE user_name LIKE '$alphabet_data%'");
                }
                foreach($n as $row_data){
                    // print_r($row_data);
                $data_id = $row_data->id;
                $user_name = $row_data->user_name;
                $firm_name = $row_data->firm_name;
                $business_address = $row_data->business_address;
                ?>
                <tr>
                    <td><?= ++$key; ?></td>
                    <td><?= $user_name; ?></td>
                    <td><?= $firm_name; ?></td>
                    <td><?= $business_address; ?></td>
                    <td><a href="#">View More</a></td>
                </tr>
                <?php
                }
                ?>
            </tbody>
        </table>
                    <?php
    }
    wp_die();
}
add_action( 'wp_ajax_nopriv_get_pagination_ajax', 'get_pagination_ajax' );  
add_action( 'wp_ajax_get_pagination_ajax', 'get_pagination_ajax' );
?>        
<script>
 $(document).ready(function () {
    $('#examples').DataTable({
        "bFilter": false
    });
});   
</script>        
        
        
        
        
        
        
        